diff decoders/wav.c @ 47:ea58bc3b15d7

Added init() and quit() methods.
author Ryan C. Gordon <icculus@icculus.org>
date Sat, 22 Sep 2001 14:41:38 +0000
parents c15396fc0e55
children b13fafb976be
line wrap: on
line diff
--- a/decoders/wav.c	Sat Sep 22 14:41:10 2001 +0000
+++ b/decoders/wav.c	Sat Sep 22 14:41:38 2001 +0000
@@ -41,6 +41,8 @@
 #error SOUND_SUPPORTS_WAV must be defined.
 #endif
 
+static int WAV_init(void);
+static void WAV_quit(void);
 static int WAV_open(Sound_Sample *sample, const char *ext);
 static void WAV_close(Sound_Sample *sample);
 static Uint32 WAV_read(Sound_Sample *sample);
@@ -54,9 +56,11 @@
         "http://www.icculus.org/SDL_sound/"
     },
 
-    WAV_open,       /* open() method       */
-    WAV_close,      /* close() method       */
-    WAV_read        /* read() method       */
+    WAV_init,       /*  init() method */
+    WAV_quit,       /*  quit() method */
+    WAV_open,       /*  open() method */
+    WAV_close,      /* close() method */
+    WAV_read        /*  read() method */
 };
 
 
@@ -90,6 +94,18 @@
 } fmt_t;
 
 
+static int WAV_init(void)
+{
+    return(1);  /* always succeeds. */
+} /* WAV_init */
+
+
+static void WAV_quit(void)
+{
+    /* it's a no-op. */
+} /* WAV_quit */
+
+
 /*
  * Read in a fmt_t from disk. This makes this process safe regardless of
  *  the processor's byte order or how the fmt_t structure is packed.